@@ -15,7 +15,7 @@ gi.require_version('Gtk', '3.0')
 gi.require_version('Gst', '1.0')
 gi.require_version('Notify', '0.7')
 gi.require_version('TotemPlParser', '1.0')
-from gi.repository import Gtk, Gio, GLib, Gdk, Gst, Notify, TotemPlParser
+from gi.repository import Gtk, Gio, GLib, Gdk, Notify, TotemPlParser
 
 from pickle import dump
 from locale import getlocale
@@ -41,10 +41,10 @@ from lollypop.window import Window
 from lollypop.database import Database
 from lollypop.player import Player
 from lollypop.art import Art
-
 from lollypop.sqlcursor import SqlCursor
 from lollypop.settings import Settings, SettingsDialog
 from lollypop.notification import NotificationManager
+from lollypop.database_history import History
 from lollypop.database_albums import AlbumsDatabase
 from lollypop.database_artists import ArtistsDatabase
 from lollypop.database_genres import GenresDatabase
@@ -113,6 +113,7 @@ class Application(Gtk.Application):
                                  "Emulate an Android Phone",
                                  None)
         self.connect('command-line', self._on_command_line)
+        self.connect('activate', self._on_activate)
         self.register(None)
         if self.get_is_remote():
             Gdk.notify_startup_complete()
@@ -135,6 +136,8 @@ class Application(Gtk.Application):
                                              Gtk.STYLE_PROVIDER_PRIORITY_USER)
         self.settings = Settings.new()
         ArtSize.BIG = self.settings.get_value('cover-size').get_int32()
+        # For a 200 album artwork, we want a 60 artist artwork
+        ArtSize.ARTIST_SMALL = ArtSize.BIG * 60 / 200
         self.db = Database()
         self.playlists = Playlists()
         # We store cursors for main thread
@@ -147,6 +150,8 @@ class Application(Gtk.Application):
         self.player = Player()
         self.scanner = CollectionScanner()
         self.art = Art()
+        if self.settings.get_value('artist-artwork'):
+            GLib.timeout_add(5000, self.art.cache_artists_art)
         if LastFM is not None:
             self.lastfm = LastFM()
         if not self.settings.get_value('disable-mpris'):
@@ -267,7 +272,6 @@ class Application(Gtk.Application):
         except Exception as e:
             print("Application::quit(): ", e)
         self.window.destroy()
-        Gst.deinit()
 
     def is_fullscreen(self):
         """
@@ -387,6 +391,13 @@ class Application(Gtk.Application):
         if not self.window.is_visible():
             self.prepare_to_exit()
 
+    def _on_activate(self, application):
+        """
+            Call default handler
+            @param application as Gio.Application
+        """
+        self.window.present()
+
     def _settings_dialog(self, action=None, param=None):
         """
             Show settings dialog
@@ -404,6 +415,11 @@ class Application(Gtk.Application):
         """
         builder = Gtk.Builder()
         builder.add_from_resource('/org/gnome/Lollypop/AboutDialog.ui')
+        if self.scanner.is_locked():
+            builder.get_object('button').set_sensitive(False)
+        builder.get_object('button').connect('clicked',
+                                             self._on_reset_clicked,
+                                             builder.get_object('progress'))
         artists = self.artists.count()
         albums = self.albums.count()
         tracks = self.tracks.count()
@@ -493,3 +509,59 @@ class Application(Gtk.Application):
         self.add_action(quitAction)
 
         return menu
+
+    def _reset_database(self, track_ids, count, history, progress):
+        """
+            Backup database and reset
+            @param track ids as [int]
+            @param count as int
+            @param history as History
+            @param progress as Gtk.ProgressBar
+        """
+        if track_ids:
+            track_id = track_ids.pop(0)
+            filepath = self.tracks.get_path(track_id)
+            name = GLib.path_get_basename(filepath)
+            album_id = self.tracks.get_album_id(track_id)
+            popularity = self.tracks.get_popularity(track_id)
+            ltime = self.tracks.get_ltime(track_id)
+            mtime = self.albums.get_mtime(album_id)
+            duration = self.tracks.get_duration(track_id)
+            album_popularity = self.albums.get_popularity(album_id)
+            history.add(name, duration, popularity,
+                        ltime, mtime, album_popularity)
+            progress.set_fraction((count - len(track_ids))/count)
+            GLib.idle_add(self._reset_database, track_ids,
+                          count, history, progress)
+        else:
+            progress.hide()
+            for artist in self.artists.get([]):
+                self.art.emit('artist-artwork-changed', artist[1])
+            os.remove(Database.DB_PATH)
+            self.db = Database()
+            self.window.show_genres(self.settings.get_value('show-genres'))
+            self.window.show()
+            self.window.update_db()
+            progress.get_toplevel().set_deletable(True)
+
+    def _on_reset_clicked(self, widget, progress):
+        """
+            Reset database
+            @param widget as Gtk.Widget
+            @param progress as Gtk.ProgressBar
+        """
+        try:
+            self.player.stop()
+            self.player.reset_pcn()
+            self.player.emit('current-changed')
+            self.player.emit('prev-changed')
+            self.player.emit('next-changed')
+            self.cursors = {}
+            track_ids = self.tracks.get_ids()
+            progress.show()
+            history = History()
+            widget.get_toplevel().set_deletable(False)
+            widget.set_sensitive(False)
+            self._reset_database(track_ids, len(track_ids), history, progress)
+        except Exception as e:
+            print("Application::_on_reset_clicked():", e)
