@@ -28,6 +28,8 @@ class BaseArt(GObject.GObject):
     _CACHE_PATH = os.path.expanduser("~") + "/.cache/lollypop"
     __gsignals__ = {
         'album-artwork-changed': (GObject.SignalFlags.RUN_FIRST, None, (int,)),
+        'artist-artwork-changed': (GObject.SignalFlags.RUN_FIRST,
+                                   None, (str,)),
         'radio-artwork-changed': (GObject.SignalFlags.RUN_FIRST, None, (str,))
     }
 
@@ -76,12 +78,13 @@ class BaseArt(GObject.GObject):
         """
         return "%s/%s_%s.jpg" % (self._CACHE_PATH, icon_name, size)
 
-    def _get_default_icon(self, size, icon_name):
+    def _get_default_icon(self, icon_name, size, scale):
         """
             Construct an empty cover album,
             code forked Gnome Music, see copyright header
-            @param size as int
             @param icon_name as str
+            @param size as int
+            @param scale factor as int
             @return pixbuf as cairo.Surface
         """
         # First look in cache
@@ -120,6 +123,6 @@ class BaseArt(GObject.GObject):
             except:
                 pixbuf.savev(cache_path_jpg, "jpeg",
                              ["quality"], ["90"])
-        surface = Gdk.cairo_surface_create_from_pixbuf(pixbuf, 0, None)
+        surface = Gdk.cairo_surface_create_from_pixbuf(pixbuf, scale, None)
         del pixbuf
         return surface
