@@ -135,6 +135,8 @@ class CollectionScanner(GObject.GObject, ScannerTagReader):
         """
         self.stop()
         self.emit("scan-finished")
+        if Lp().settings.get_value('artist-artwork'):
+            Lp().art.cache_artists_art()
         if self._missing_codecs is not None:
             Lp().player.load_external(
                                     GLib.filename_to_uri(self._missing_codecs))
@@ -240,6 +242,8 @@ class CollectionScanner(GObject.GObject, ScannerTagReader):
             album_artists = composers
             if artists == '':
                 artists = album_artists
+            if artists == '':
+                artists = _("Unknown")
 
         debug("CollectionScanner::add2db(): Restore stats")
         # Restore stats
