@@ -169,7 +169,10 @@ class Container:
         """
         self._show_genres = show
         self._list_one.clear()
+        self._list_two.clear()
+        self._list_two.hide()
         self._update_list_one(None)
+        self._list_one.select_ids([Type.POPULARS])
 
     def destroy_current_view(self):
         """
@@ -208,9 +211,13 @@ class Container:
             if not values_one:
                 values_one = [Type.POPULARS]
             self._list_one.select_ids([])
+            self._list_one.clear()
+            self._update_list_one(None)
             self._list_one.select_ids(values_one)
         if self._list_two.is_visible():
             self._list_two.select_ids([])
+            self._list_two.clear()
+            self._update_list_two(None)
             self._list_two.select_ids(values_two)
 
     def pulse(self, pulse):
