@@ -13,8 +13,6 @@
 
 from gi.repository import GLib
 
-from cgi import escape
-
 from lollypop.radios import Radios
 from lollypop.define import Lp, Type
 
@@ -114,6 +112,14 @@ class Disc:
                                                       self.album.genre_ids,
                                                       self.album.artist_ids,
                                                       self.number)
+            # If user tagged track with an artist not present in album
+            if not self._track_ids:
+                print("%s missing an album artist in artists" %
+                      self.album.name)
+                self._track_ids = self.db.get_disc_tracks(self.album.id,
+                                                          self.album.genre_ids,
+                                                          [],
+                                                          self.number)
         return self._track_ids
 
     @property
@@ -182,6 +188,12 @@ class Album(Base):
             self._tracks_ids = self.db.get_tracks(self.id,
                                                   self.genre_ids,
                                                   self.artist_ids)
+            # If user tagged track with an artist not present in album
+            if not self._tracks_ids:
+                print("%s missing an album artist in artists" % self.name)
+                self._tracks_ids = self.db.get_tracks(self.id,
+                                                      self.genre_ids,
+                                                      [])
         return self._tracks_ids
 
     @property
@@ -222,27 +234,24 @@ class Track(Base):
         Base.__init__(self, Lp().tracks)
         self.id = track_id
         self._uri = None
+        self._non_album_artists = []
 
-    def formated_name(self):
+    @property
+    def non_album_artists(self):
         """
-            Return formated name (title \n artist)
+            Return non album artists
             @return str
         """
-        name = escape(self.name)
-        artists = []
-        album_artist_ids = self.album.artist_ids
-        # Show all artists for compilations
-        if album_artist_ids[0] == Type.COMPILATIONS:
-            artists = self.artists
-        # Show only non album artist for albums (and only if one)
-        elif not Lp().settings.get_value('hide-artists') and\
-                len(self.artists) > 1:
-            for artist in self.artists:
-                if artist not in self.album_artists:
-                    artists.append(artist)
-        if artists:
-            name = "<b>%s</b> - %s" % (escape(", ".join(artists)), name)
-        return name
+        if not self._non_album_artists:
+            # Show all artists for compilations
+            if self.album.artist_ids[0] == Type.COMPILATIONS:
+                self._non_album_artists = self.artists
+            # Show only non album artist for albums (and only if one)
+            elif len(self.artists) > 1:
+                for artist in self.artists:
+                    if artist not in self.album_artists:
+                        self._non_album_artists.append(artist)
+        return self._non_album_artists
 
     @property
     def title(self):
