@@ -76,17 +76,16 @@ class InfoPopover(Gtk.Popover):
         if Lp().settings.get_value('inforeload'):
             builder.get_object('reload').get_style_context().add_class(
                                                                     'selected')
-        if not show_albums:
-            self._stack.get_child_by_name('albums').destroy()
-        if InfoPopover.Wikipedia is None:
-            self._stack.get_child_by_name('wikipedia').destroy()
-        if Lp().lastfm is None:
-            self._stack.get_child_by_name('lastfm').destroy()
-        if artist_ids:
-            self._stack.get_child_by_name('lyrics').destroy()
-        if InfoPopover.WebView is None:
-            self._stack.get_child_by_name('duck').destroy()
-            self._stack.get_child_by_name('lyrics').destroy()
+        if show_albums:
+            self._stack.get_child_by_name('albums').show()
+        if InfoPopover.Wikipedia is not None:
+            self._stack.get_child_by_name('wikipedia').show()
+        if Lp().lastfm is not None:
+            self._stack.get_child_by_name('lastfm').show()
+        if InfoPopover.WebView is not None:
+            self._stack.get_child_by_name('duck').show()
+            if not artist_ids:
+                self._stack.get_child_by_name('lyrics').show()
         self._stack.set_visible_child_name(
             Lp().settings.get_value('infoswitch').get_string())
 
@@ -125,6 +124,8 @@ class InfoPopover(Gtk.Popover):
             Update content on track changed
             @param player as Player
         """
+        if self._artist_ids:
+            return
         self._current_track = Lp().player.current_track
         name = self._stack.get_visible_child_name()
         if name == "albums":
@@ -206,7 +207,6 @@ class InfoPopover(Gtk.Popover):
             @param widget as Gtk.Grid
         """
         self._jump_button.show()
-        self._jump_button.set_tooltip_text(_("Go to current track"))
         if self._current_track.id is None:
             self._current_track = Lp().player.current_track
         Lp().settings.set_value('infoswitch',
