@@ -48,7 +48,8 @@ class NextPopover(Gtk.Popover):
         self._title_label.set_text(Lp().player.next_track.title)
         art = Lp().art.get_album_artwork(
                                Lp().player.next_track.album,
-                               ArtSize.MEDIUM * self.get_scale_factor())
+                               ArtSize.MEDIUM,
+                               self.get_scale_factor())
         if art is not None:
             self._cover.set_from_surface(art)
             del art
