@@ -307,7 +307,8 @@ class SearchPopover(Gtk.Popover):
                 search_row.set_cover(
                         Lp().art.get_album_artwork(
                                      Album(album_id),
-                                     ArtSize.MEDIUM*self.get_scale_factor()))
+                                     ArtSize.MEDIUM,
+                                     self.get_scale_factor()))
                 if result.is_track:
                     self._view.prepend(search_row)
                 else:
@@ -392,8 +393,7 @@ class SearchPopover(Gtk.Popover):
 
     def _on_search_changed(self, widget):
         """
-            Timeout filtering, call _really_do_filterting()
-            after timeout
+            Timeout filtering
             @param widget as Gtk.TextEntry
         """
         if self._in_thread:
@@ -415,7 +415,7 @@ class SearchPopover(Gtk.Popover):
 
     def _on_search_changed_thread(self):
         """
-            Just run _reallyon_entry_changed in a thread
+            Populate widget
         """
         self._timeout = None
         self._in_thread = True
