@@ -14,6 +14,7 @@ from gi.repository import Gtk, GLib, Gio, GdkPixbuf, Gdk, Pango
 
 from threading import Thread
 from gettext import gettext as _
+from cgi import escape
 
 from lollypop.radios import Radios
 from lollypop.tunein import TuneIn
@@ -38,6 +39,7 @@ class TuneinPopover(Gtk.Popover):
         else:
             self._radios_manager = Radios()
         self._current_url = None
+        self._timeout_id = None
         self._previous_urls = []
         self._covers_to_download = []
 
@@ -49,7 +51,7 @@ class TuneinPopover(Gtk.Popover):
         builder.add_from_resource('/org/gnome/Lollypop/TuneinPopover.ui')
         builder.connect_signals(self)
         widget = builder.get_object('widget')
-        widget.attach(self._stack, 0, 2, 4, 1)
+        widget.attach(self._stack, 0, 2, 5, 1)
 
         self._back_btn = builder.get_object('back_btn')
         self._home_btn = builder.get_object('home_btn')
@@ -83,26 +85,29 @@ class TuneinPopover(Gtk.Popover):
             Populate views
             @param url as string
         """
-        if not self._view.get_children() or\
-           self._stack.get_visible_child_name() == "notfound":
-            self._stack.set_visible_child_name('spinner')
-            self._current_url = url
-            self._clear()
-            self._back_btn.set_sensitive(False)
-            self._home_btn.set_sensitive(False)
-            self._label.set_text(_("Please wait..."))
-            t = Thread(target=self._populate, args=(url,))
-            t.daemon = True
-            t.start()
+        if url is None and self._current_url is not None:
+            return
+        self._spinner.start()
+        self._clear()
+        self._stack.set_visible_child_name('spinner')
+        self._current_url = url
+        self._back_btn.set_sensitive(False)
+        self._home_btn.set_sensitive(False)
+        self._label.set_text(_("Please wait..."))
+        t = Thread(target=self._populate, args=(url,))
+        t.daemon = True
+        t.start()
 
 #######################
 # PRIVATE             #
 #######################
-    def _show_not_found(self):
+    def _show_not_found(self, message=""):
         """
             Show not found message
+            @param message as str
         """
-        self._label.set_text(_("Can't connect to TuneIn..."))
+        # TODO Add a string
+        self._label.set_text(message)
         self._stack.set_visible_child_name('notfound')
         self._home_btn.set_sensitive(True)
 
@@ -112,32 +117,42 @@ class TuneinPopover(Gtk.Popover):
             @param url as string
             @thread safe
         """
-        if url is None:
-            items = self._tunein.get_items()
-        else:
-            items = self._tunein.get_items(url)
+        try:
+            if url is None:
+                items = self._tunein.get_items(
+                                    "http://opml.radiotime.com/Browse.ashx?c=")
+            else:
+                items = self._tunein.get_items(url)
 
-        if items:
-            self._add_items(items)
-        else:
-            GLib.idle_add(self._show_not_found)
+            if self._current_url == url:
+                if items:
+                    self._add_items(items, url)
+                else:
+                    GLib.idle_add(self._show_not_found)
+        except:
+            GLib.idle_add(self._show_not_found,
+                          _("Can't connect to TuneIn..."))
 
-    def _add_items(self, items):
+    def _add_items(self, items, url):
         """
             Add current items
             @param items as [TuneItem]
+            @parma url as str
             @thread safe
         """
-        GLib.idle_add(self._add_item, items)
+        GLib.idle_add(self._add_item, items, url)
 
-    def _add_item(self, items):
+    def _add_item(self, items, url):
         """
             Add item
             @param items as [TuneItem]
+            @param url as str
         """
+        if url != self._current_url:
+            return
         if not items:
             self._home_btn.set_sensitive(self._current_url is not None)
-            t = Thread(target=self._download_images)
+            t = Thread(target=self._download_images, args=(url,))
             t.daemon = True
             t.start()
             return
@@ -177,17 +192,18 @@ class TuneinPopover(Gtk.Popover):
         if self._stack.get_visible_child_name() == 'spinner':
             self._stack.set_visible_child_name('scrolled')
             self._spinner.stop()
-            self._label.set_text(_("Browse themes and add a new radio"))
+            self._label.set_text("")
             if self._current_url is not None:
                 self._back_btn.set_sensitive(True)
-        GLib.idle_add(self._add_items, items)
+        GLib.idle_add(self._add_items, items, url)
 
-    def _download_images(self):
+    def _download_images(self, url):
         """
             Download and set image for TuneItem
+            @param url as str
             @thread safe
         """
-        while self._covers_to_download:
+        while self._covers_to_download and url == self._current_url:
             (item, image) = self._covers_to_download.pop(0)
             try:
                 f = Gio.File.new_for_uri(item.LOGO)
@@ -274,9 +290,6 @@ class TuneinPopover(Gtk.Popover):
         """
         self._current_url = None
         self._previous_urls = []
-        self._stack.set_visible_child_name('spinner')
-        self._spinner.start()
-        self._clear()
         self.populate()
 
     def _on_activate_link(self, link, item):
@@ -286,9 +299,6 @@ class TuneinPopover(Gtk.Popover):
             @param item as TuneIn Item
         """
         if item.TYPE == "link":
-            self._stack.set_visible_child_name('spinner')
-            self._spinner.start()
-            self._clear()
             self._scrolled.get_vadjustment().set_value(0.0)
             if self._current_url is not None:
                 self._previous_urls.append(self._current_url)
@@ -311,7 +321,40 @@ class TuneinPopover(Gtk.Popover):
             @param link as Gtk.Button
             @param item as TuneIn Item
         """
+        self._timeout_id = None
         t = Thread(target=self._add_radio, args=(item,))
         t.daemon = True
         t.start()
         self.hide()
+
+    def _on_search_changed(self, widget):
+        """
+            Timeout filtering, call _really_do_filterting()
+            after timeout
+            @param widget as Gtk.TextEntry
+        """
+        self._current_url = None
+        if self._timeout_id is not None:
+            GLib.source_remove(self._timeout_id)
+            self._timeout_id = None
+
+        text = widget.get_text()
+        if text != "":
+            self._home_btn.set_sensitive(True)
+            self._timeout_id = GLib.timeout_add(1000,
+                                                self._on_search_changed_thread,
+                                                text)
+        else:
+            self._home_btn.set_sensitive(False)
+            self._timeout_id = GLib.timeout_add(1000,
+                                                self._on_home_btn_clicked,
+                                                None)
+
+    def _on_search_changed_thread(self, string):
+        """
+            Populate widget
+            @param string as str
+        """
+        self._timeout_id = None
+        url = "http://opml.radiotime.com/Search.ashx?query=%s" % escape(string)
+        self.populate(url)
