@@ -21,6 +21,7 @@ from gettext import gettext as _
 from threading import Thread
 
 from lollypop.define import Lp, Type, SecretSchema, SecretAttributes, ArtSize
+from lollypop.cache import InfoCache
 
 
 class Settings(Gio.Settings):
@@ -116,8 +117,8 @@ class SettingsDialog:
         switch_compilations.set_state(
             Lp().settings.get_value('show-compilations'))
 
-        switch_artists = builder.get_object('switch_artists')
-        switch_artists.set_state(Lp().settings.get_value('hide-artists'))
+        switch_artwork = builder.get_object('switch_artwork')
+        switch_artwork.set_state(Lp().settings.get_value('artist-artwork'))
 
         switch_repeat = builder.get_object('switch_repeat')
         switch_repeat.set_state(not Lp().settings.get_value('repeat'))
@@ -250,6 +251,13 @@ class SettingsDialog:
         value = widget.get_value()
         Lp().settings.set_value('cover-size', GLib.Variant('i', value))
         ArtSize.BIG = value
+        for suffix in ["lastfm", "wikipedia", "spotify"]:
+            for artist in Lp().artists.get([]):
+                InfoCache.uncache_artwork(artist[1], suffix,
+                                          widget.get_scale_factor())
+                Lp().art.emit('artist-artwork-changed', artist[1])
+        # For a 200 album artwork, we want a 60 artist artwork
+        ArtSize.ARTIST_SMALL = ArtSize.BIG * 60 / 200
         Lp().window.reload_view()
 
     def _update_ui_setting(self, widget, state):
@@ -337,13 +345,16 @@ class SettingsDialog:
         Lp().settings.set_value('show-compilations',
                                 GLib.Variant('b', state))
 
-    def _update_artists_setting(self, widget, state):
+    def _update_artwork_setting(self, widget, state):
         """
-            Update compilations setting
+            Update artist artwork setting
             @param widget as unused, state as widget state
         """
-        Lp().settings.set_value('hide-artists',
+        Lp().settings.set_value('artist-artwork',
                                 GLib.Variant('b', state))
+        Lp().window.reload_view()
+        if state:
+            Lp().art.cache_artists_art()
 
     def _update_repeat_setting(self, widget, state):
         """
