@@ -20,7 +20,7 @@ from lollypop.widgets_track import TracksWidget, TrackRow
 from lollypop.objects import Track
 from lollypop.widgets_rating import RatingWidget
 from lollypop.pop_menu import AlbumMenu
-from lollypop.pop_covers import CoversPopover
+from lollypop.pop_artwork import CoversPopover
 from lollypop.objects import Album
 
 
@@ -59,7 +59,8 @@ class AlbumWidget:
             return
         surface = Lp().art.get_album_artwork(
                             self._album,
-                            ArtSize.BIG * self._cover.get_scale_factor())
+                            ArtSize.BIG,
+                            self._cover.get_scale_factor())
         self._cover.set_from_surface(surface)
         self._cover.set_size_request(100, 100)
         if surface.get_height() > surface.get_width():
@@ -76,7 +77,8 @@ class AlbumWidget:
             return
         surface = Lp().art.get_album_artwork(
                             self._album,
-                            ArtSize.BIG * self._cover.get_scale_factor())
+                            ArtSize.BIG,
+                            self._cover.get_scale_factor())
         self._cover.set_from_surface(surface)
         if surface.get_height() > surface.get_width():
             self._overlay_orientation = Gtk.Orientation.VERTICAL
@@ -314,9 +316,8 @@ class AlbumWidget:
             @param: widget as Gtk.EventBox
             @param: event as Gdk.Event
         """
-        popover = CoversPopover(self._album.artist_id, self._album.id)
+        popover = CoversPopover(self._album)
         popover.set_relative_to(widget)
-        popover.populate()
         popover.connect('closed', self._on_pop_cover_closed)
         # Disable hidding overlay
         self._show_overlay = False
@@ -444,8 +445,8 @@ class AlbumSimpleWidget(Gtk.FlowBoxChild, AlbumWidget):
             Return preferred width
             @return (int, int)
         """
-        # Padding: 3px, border: 1px
-        width = ArtSize.BIG + 8
+        # Padding: 3px, border: 1px + spacing
+        width = ArtSize.BIG + 12
         return (width, width)
 
     def set_overlay(self, set):
@@ -584,10 +585,7 @@ class AlbumDetailedWidget(Gtk.Bin, AlbumWidget):
         """
         Gtk.Bin.__init__(self)
         AlbumWidget.__init__(self, album_id, genre_ids)
-        # Check if we need to limit the view to artist album
-        for artist_id in self._album.artist_ids:
-            if artist_id in artist_ids:
-                self._album.set_artists(artist_ids)
+        self._album.set_artists(artist_ids)
         self._width = None
         # Cover + rating + spacing
         self._height = ArtSize.BIG + 26
