@@ -37,7 +37,8 @@ class Window(Gtk.ApplicationWindow, Container):
         Gtk.ApplicationWindow.__init__(self,
                                        application=app,
                                        title="Lollypop")
-        self.connect('notify::is-active', self._on_active)
+        self.connect('hide', self._on_hide)
+        self.connect('leave-notify-event', self._on_leave_notify)
         self._timeout_configure = None
         seek_action = Gio.SimpleAction.new('seek',
                                            GLib.VariantType.new('i'))
@@ -124,18 +125,6 @@ class Window(Gtk.ApplicationWindow, Container):
             self._app.set_accels_for_action("app.player::next_album", [None])
             self._app.set_accels_for_action("app.player::prev", [None])
 
-    def do_hide(self):
-        """
-            Remove callbacks (we don't want to save an invalid value on hide
-        """
-        if self._signal1 is not None:
-            self.disconnect(self._signal1)
-            self._signal1 = None
-        if self._signal2 is not None:
-            self.disconnect(self._signal2)
-            self._signal2 = None
-        Gtk.ApplicationWindow.do_hide(self)
-
     def setup_window(self):
         """
             Setup window position and size, callbacks
@@ -157,9 +146,6 @@ class Window(Gtk.ApplicationWindow, Container):
         """
         size = self.get_size()
         self._toolbar.set_content_width(size[0])
-        view = self._stack.get_visible_child()
-        if view and hasattr(view, 'show_context'):
-            view.show_context(size[0] > WindowSize.MEDIUM)
         if Lp().player.current_track.id is not None:
             self._show_miniplayer(size[0] < WindowSize.MEDIUM)
             self._show_subtoolbar(size[0] < WindowSize.MONSTER and
@@ -184,6 +170,13 @@ class Window(Gtk.ApplicationWindow, Container):
             self._setup_pos_size('window')
         self._was_maximized = was_maximized
 
+    @property
+    def toolbar(self):
+        """
+            toolbar as Toolbar
+        """
+        return self._toolbar
+
 ############
 # Private  #
 ############
@@ -330,6 +323,18 @@ class Window(Gtk.ApplicationWindow, Container):
         self._main_stack.add_named(self.main_widget(), 'main')
         self._main_stack.set_visible_child_name('main')
 
+    def _on_hide(self, window):
+        """
+            Remove callbacks (we don't want to save an invalid value on hide
+            @param window as GtkApplicationWindow
+        """
+        if self._signal1 is not None:
+            self.disconnect(self._signal1)
+            self._signal1 = None
+        if self._signal2 is not None:
+            self.disconnect(self._signal2)
+            self._signal2 = None
+
     def _on_configure_event(self, widget, event):
         """
             Delay event
@@ -397,7 +402,7 @@ class Window(Gtk.ApplicationWindow, Container):
             @param param as GLib.Variant
         """
         seconds = param.get_int32()
-        position = Lp().player.get_position_in_track()
+        position = Lp().player.position
         seek = position/1000000/60+seconds
         if seek < 0:
             seek = 0
@@ -429,7 +434,7 @@ class Window(Gtk.ApplicationWindow, Container):
                 # We send this signal to update next popover
                 Lp().player.emit('queue-changed')
             else:
-                Lp().player.context.next = NextContext.START_NEW_ALBUM
+                Lp().player.set_next_context(NextContext.START_NEW_ALBUM)
                 Lp().player.set_next()
                 Lp().player.next()
         elif string == "prev":
@@ -446,11 +451,10 @@ class Window(Gtk.ApplicationWindow, Container):
             # initialisation is finished...
             GLib.timeout_add(2000, self.update_db)
 
-    def _on_active(self, window, active):
+    def _on_leave_notify(self, widget, event):
         """
-            Clean overlays if not active
-            @param widget as Gtk.Window
-            @param active as boolean
+            Update overlays as internal widget may not have received the signal
+            @param widget as Gtk.Widget
+            @param event as Gdk.event
         """
-        if not window.is_active():
-            self.update_overlays()
+        self.disable_overlays()
